;(function () {

    {% comment %}
    /**
     * Принимает идентификаторы компонент:
     *      Поля "Статус";
     *      Поля "Комментарий";
     *      Поля "Причина отказа";
     *
     * Значение идентификатора статуса "Отказано в услуге".
     *
     * */
    {% endcomment %}
    var declarationStatusField = Ext.getCmp("{{ component.field__status_id.client_id }}");
    var commentField = Ext.getCmp("{{ component.field__comment.client_id }}");
    var declarationRejectReasonField = Ext.getCmp("{{ component.declaration_reject_reason.client_id }}");
    var declarationStatusReject = "{{ component.declaration_status_reject }}";
    var commentAllowBlank = "{{ component.comment_allow_blank }}" === "True";

    {% comment %}
    /* Сохраняет валидатор поля "Комментарий". */
    {% endcomment %}
    var commentFieldValidator = commentField.validator;


    {% comment %}
    /**
     * Функция-обработчик события изменения значения поля "Статус".
     *
     * Если поле было изменено на значение "Отказано в услуге", то зависимое поле "Комментарий"
     * становится невидимым и необязательным. Изменяемое поля становится доступным на редактирование. И наоборот.
     *
     */
    {% endcomment %}
    function declarationStatusChangeHandler() {
        var visibleRejectReasonField = declarationStatusField.getValue()  == declarationStatusReject;

        declarationRejectReasonField.setVisible(visibleRejectReasonField);
        declarationRejectReasonField.setDisabled(!visibleRejectReasonField);

        commentField.setVisible(!visibleRejectReasonField);
        commentField.validator = (visibleRejectReasonField) ? null : commentFieldValidator;
        commentField.allowBlank = (visibleRejectReasonField) ? visibleRejectReasonField : commentAllowBlank;
        commentField.validate();
    }

    {% comment %}
    /**
     * Функция-обработчик события изменения значения поля "Причина отказа".
     *
     * Если поле было изменено, то в зависимое поле "Комментарий" устанавливается текстовое значение изменяемого поля.
     * Сделано для обратной совместимости.
     *
     */
    {% endcomment %}
    function declarationRejectReasonChangeHandler() {
        commentField.setValue(
            declarationRejectReasonField.getStore().data.get(declarationRejectReasonField.getValue()).data.name);
        commentField.validate();
    }

    {% comment %}
    /**
     * Устанавливает начальное состояние полей и прочие настройки.
     *
     * */
    {% endcomment %}
    function setInitialState() {
        declarationStatusChangeHandler();
    }

    {% comment %}
    /**
     * Устанавливает обработчики полям.
     *
     * */
    {% endcomment %}
    function setHandler() {
        declarationStatusField.on("select", declarationStatusChangeHandler);
        declarationRejectReasonField.on("select", declarationRejectReasonChangeHandler);
    }

    setInitialState();
    setHandler();

})();